array2df: Array to long-format data frame

View source: R/array2df.R

array2dfR Documentation

Array to long-format data frame

Description

Organizes the information in an array with N dimensions into a long-format data frame with N + 1 columns, where the last column contains the values of the array.

Usage

array2df(arr, value_name = "value")

Arguments

arr

An array of N-dimensiones

value_name

Name for the column containing the values of the array.

Author(s)

Jose M. Pavia, pavia@uv.es


WIPF documentation built on March 7, 2026, 1:07 a.m.

Related to array2df in WIPF...