| array2df | R Documentation |
Organizes the information in an array with N dimensions into a long-format data frame with N + 1 columns, where the last column contains the values of the array.
array2df(arr, value_name = "value")
arr |
An array of N-dimensiones |
value_name |
Name for the column containing the values of the array. |
Jose M. Pavia, pavia@uv.es
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.